@@ -81,6 +81,7 @@ class LightningModule(
             "truncated_bptt_steps",
             "use_amp",
             "trainer",
+            "_running_torchscript",
         ]
         + DeviceDtypeModuleMixin.__jit_unused_properties__
         + HyperparametersMixin.__jit_unused_properties__
@@ -109,8 +110,7 @@ class LightningModule(
         self._param_requires_grad_state = {}
         self._metric_attributes: Optional[Dict[int, str]] = None
         self._should_prevent_trainer_and_dataloaders_deepcopy: bool = False
-        # TODO: remove in 1.8
-        self._running_torchscript = False
+        self._running_torchscript_internal = False  # workaround for https://github.com/pytorch/pytorch/issues/67146
 
         self._register_sharded_tensor_state_dict_hooks_if_available()
 
@@ -289,6 +289,35 @@ class LightningModule(
         """Reference to the list of loggers in the Trainer."""
         return self.trainer.loggers if self._trainer else []
 
+    @property
+    def _running_torchscript(self) -> bool:
+        return self._running_torchscript_internal
+
+    @_running_torchscript.setter
+    def _running_torchscript(self, value: bool) -> None:
+        for v in self.children():
+            if isinstance(v, LightningModule):
+                v._running_torchscript = value
+        self._running_torchscript_internal = value
+
+    def _call_batch_hook(self, hook_name: str, *args: Any) -> Any:
+        if self._trainer:
+            datahook_selector = self._trainer._data_connector._datahook_selector
+            assert datahook_selector is not None
+            obj = datahook_selector.get_instance(hook_name)
+            if isinstance(obj, self.__class__):
+                trainer_method = self._trainer._call_lightning_module_hook
+            else:
+                trainer_method = self._trainer._call_lightning_datamodule_hook
+
+            return trainer_method(hook_name, *args)
+        else:
+            hook = getattr(self, hook_name)
+            return hook(*args)
+
+    def _on_before_batch_transfer(self, batch: Any, dataloader_idx: int = 0) -> Any:
+        return self._call_batch_hook("on_before_batch_transfer", batch, dataloader_idx)
+
     def _apply_batch_transfer_handler(
         self, batch: Any, device: Optional[torch.device] = None, dataloader_idx: int = 0
     ) -> Any:
@@ -552,7 +581,11 @@ class LightningModule(
         raise ValueError(f"`self.log({name}, {value})` was called, but `{type(v).__name__}` values cannot be logged")
 
     def __to_tensor(self, value: Union[torch.Tensor, numbers.Number], name: str) -> Tensor:
-        value = torch.tensor(value, device=self.device)
+        value = (
+            value.clone().detach().to(self.device)
+            if isinstance(value, torch.Tensor)
+            else torch.tensor(value, device=self.device)
+        )
         if not torch.numel(value) == 1:
             raise ValueError(
                 f"`self.log({name}, {value})` was called, but the tensor must have a single element."
